@@ -17,11 +17,11 @@ Net::Dogstatsd - Perl client to Datadog's dogstatsd metrics collector.
 
 =head1 VERSION
 
-Version 1.0.2
+Version 1.0.3
 
 =cut
 
-our $VERSION = '1.0.2';
+our $VERSION = '1.0.3';
 
 
 =head1 SYNOPSIS
@@ -31,36 +31,37 @@ via dogstatsd, a local daemon installed by Datadog agent package.
 
 	use Net::Dogstatsd;
 
-	# Create an object to communicate with Dogstatsd, using default server/port settings.
+	# Create an object to communicate with Dogstatsd, using default server and
+	# port settings.
 	my $dogstatsd = Net::Dogstatsd->new(
 		host    => 'localhost',  #optional. Default = 127.0.0.1
 		port    => '8125',       #optional. Default = 8125
 		verbose => 0,            #optional. Default = 0
 	);
-	
+
 	# Set, and print, the 'verbose' option value.
 	$dogstatsd->verbose(1);
 	print "In verbose mode." if $dogstatsd->verbose();
-	
-	# Before we can start sending metrics, we have to get or create a socket to dogstatsd
+
+	# Before sending metrics, we have to get or create a socket to dogstatsd
 	my $socket = $dogstatsd->get_socket();
-	
+
 	# Counter metrics can be incremented or decremented
-	# By default, they will be incremented or decremented by 1, unless the optional
-	# 'value' parameter is passed
+	# By default, they will be incremented or decremented by 1, unless the
+	# optional 'value' parameter is passed
 	$dogstatsd->increment(
 		name  => 'test_metric.sample_counter',
 		value => $increment_value, #optional; default = 1
 		tags  => [ 'env:production', db ], #optional
 	);
-	
+
 	$dogstatsd->decrement(
 		name  => $metric_name,
 		value => $decrement_value, #optional; default = 1
 		tags  => [ 'env:devel', web ], #optional
 	);
-	
-	
+
+
 	# Gauge metrics can be used for capturing value of something over time
 	# Example: Gas gauge, inventory level, free memory
 	$dogstatsd->gauge(
@@ -68,8 +69,8 @@ via dogstatsd, a local daemon installed by Datadog agent package.
 		value => $gauge_value, #required - must be a number
 		tags  => [ 'warehouse:us' ], #optional
 	);
-	
-	
+
+
 	# Histogram metrics measure the statistical distribution of a set of values.
 	# Provides min/max/avg as well as 75th, 85th, 95th and 99th percentiles.
 	# NOTE: do not use this for timers. Use timer() instead.
@@ -78,17 +79,17 @@ via dogstatsd, a local daemon installed by Datadog agent package.
 		value => $value,
 		tags  => [ 'tag1', 'tag2:value', 'tag3' ], #optional
 	);
-	
-	
-	# Timers are a special type of histogram. 
+
+
+	# Timers are a special type of histogram.
 	$dogstatsd->timer(
 		name  => $metric_name,
 		value => $metric_value,
 		unit  => $metric_unit, # 'ms' (milliseconds) or 's|sec' (seconds)
 		tags  => [ 'tag1', 'tag2:value', 'tag3' ], #optional
 	);
-	
-	
+
+
 	# Set metrics are special counters that can track unique elements in a group.
 	# Example: the number of unique visitors currently on a website
 	$dogstatsd->sets(
@@ -96,7 +97,7 @@ via dogstatsd, a local daemon installed by Datadog agent package.
 		value => $account_id,
 		tags  => [ 'referer:Google' ], #optional
 	);
-	
+
 =cut
 
 =head1 MAIN
@@ -132,20 +133,20 @@ Create a new Net::Dogstatsd object that will be used to interact with dogstatsd.
 sub new
 {
 	my ( $class, %args ) = @_;
-	
+
 	# Defaults
 	my $host = defined( $args{'host'} ) ? $args{'host'} : '127.0.0.1';
 	my $port = defined( $args{'port'} ) ? $args{'port'} : '8125';
 	my $verbose = defined( $args{'verbose'} ) ? $args{'verbose'} : 0;
-	
+
 	my $self = {
 		host             => $host,
 		port             => $port,
 		verbose          => $verbose,
 	};
-	
+
 	bless( $self, $class );
-	
+
 	return $self;
 }
 
@@ -162,7 +163,7 @@ Get or set the 'verbose' property.
 sub verbose
 {
 	my ( $self, $value ) = @_;
-	
+
 	if ( defined $value && $value =~ /^[01]$/ )
 	{
 		$self->{'verbose'} = $value;
@@ -171,7 +172,7 @@ sub verbose
 	{
 		return $self->{'verbose'};
 	}
-	
+
 	return;
 }
 
@@ -188,7 +189,7 @@ sub get_socket
 {
 	my ( $self ) = @_;
 	my $verbose = $self->verbose();
-	
+
 	if ( !defined $self->{'socket'} )
 	{
 		try
@@ -197,9 +198,9 @@ sub get_socket
 				PeerAddr => $self->{'host'},
 				PeerPort => $self->{'port'},
 				Proto    => 'udp'
-				) 
-			|| die "Could not open UDP connection to" . $self->{'host'} . ":" . $self->{'port'} . "\n";
-			
+				)
+			|| die 'Could not open UDP connection to' . $self->{'host'} . ':' . $self->{'port'} . "\n";
+
 		}
 		catch
 		{
@@ -207,7 +208,7 @@ sub get_socket
 			croak( "Could not open connection to metrics server. Error: >$_<" );
 		};
 	}
-	
+
 	return $self->{'socket'};
 }
 
@@ -222,7 +223,7 @@ Include optional arrayref of tags/tag-values.
 		name  => $metric_name,
 		value => $increment_value, #optional; default = 1
 	);
-	
+
 	$dogstatsd->increment(
 		name  => $metric_name,
 		value => $increment_value, #optional; default = 1
@@ -234,7 +235,7 @@ Include optional arrayref of tags/tag-values.
 sub increment
 {
 	my ( $self, %args ) = @_;
-	
+
 	$self->_counter( action => 'increment', %args );
 	return;
 }
@@ -249,7 +250,7 @@ Include optional arrayref of tags/tag-values.
 		name  => $metric_name,
 		value => $decrement_value, #optional; default = 1
 	);
-	
+
 	$dogstatsd->decrement(
 		name  => $metric_name,
 		value => $decrement_value, #optional; default = 1
@@ -261,7 +262,7 @@ Include optional arrayref of tags/tag-values.
 sub decrement
 {
 	my ( $self, %args ) = @_;
-	
+
 	$self->_counter( action => 'decrement', %args );
 	return;
 }
@@ -277,7 +278,7 @@ Include optional arrayref of tags/tag-values.
 		name  => $metric_name,
 		value => $gauge_value,
 	);
-	
+
 	$dogstatsd->gauge(
 		name  => $metric_name,
 		value => $gauge_value,
@@ -290,21 +291,21 @@ sub gauge
 {
 	my ( $self, %args ) = @_;
 	my $verbose = $self->verbose();
-	
+
 	# Check for mandatory parameters
 	foreach my $arg ( qw( name  value ) )
 	{
 		croak "Argument '$arg' is a required argument"
 			if !defined( $args{$arg} ) || ( $args{$arg} eq '' );
 	}
-	
+
 	# Check that value is a number
 	croak "Value >$args{'value'}< is not a number, which is required for gauge()"
 		unless Data::Validate::Type::is_number( $args{'value'} );
-	
+
 	# Error checks common to all metric types
 	$self->_error_checks( %args );
-	
+
 	$self->_send_metric(
 		type        => 'gauge',
 		value       => $args{'value'},
@@ -312,14 +313,15 @@ sub gauge
 		tags        => defined $args{'tags'} ? $args{'tags'} : [],
 		sample_rate => defined $args{'sample_rate'} ? $args{'sample_rate'} : 1,
 	);
-	
+
 	return;
 }
 
 
 =head2 histogram()
 
-Send a 'histogram' metric. Provides min/max/avg as well as 75th, 85th, 95th and 99th percentiles.
+Send a 'histogram' metric. Provides min/max/avg as well as 75th, 85th, 95th and
+99th percentiles.
 NOTE: do not use this for timers. Use timer() instead.
 Include optional arrayref of tags/tag-values.
 
@@ -327,7 +329,7 @@ Include optional arrayref of tags/tag-values.
 		name  => $metric_name,
 		value => $value,
 	);
-	
+
 	$dogstatsd->histogram(
 		name  => $metric_name,
 		value => $value,
@@ -340,24 +342,21 @@ sub histogram
 {
 	my ( $self, %args ) = @_;
 	my $verbose = $self->verbose();
-	
+
 	# Check for mandatory parameters
 	foreach my $arg ( qw( name  value ) )
 	{
 		croak "Argument '$arg' is a required argument"
 			if !defined( $args{$arg} ) || ( $args{$arg} eq '' );
 	}
-	
+
 	# Check that value is a number
-	if ( defined( $args{'value' } ) )
-	{
-		croak "Value >$args{'value'}< is not a number, which is required for histogram()"
-			unless Data::Validate::Type::is_number( $args{'value'} );
-	}
-	
+	croak "Value >$args{'value'}< is not a number, which is required for histogram()"
+		unless Data::Validate::Type::is_number( $args{'value'} );
+
 	# Error checks common to all metric types
 	$self->_error_checks( %args );
-	
+
 	$self->_send_metric(
 		type        => 'histogram',
 		value       => $args{'value'},
@@ -365,14 +364,15 @@ sub histogram
 		tags        => defined $args{'tags'} ? $args{'tags'} : [],
 		sample_rate => defined $args{'sample_rate'} ? $args{'sample_rate'} : 1,
 	);
-	
+
 	return;
 }
 
 
 =head2 timer()
 
-Send a 'timer' metric. Provides min/max/avg as well as 75th, 85th, 95th and 99th percentiles.
+Send a 'timer' metric. Provides min/max/avg as well as 75th, 85th, 95th
+and 99th percentiles.
 Ex: time to run a database query.
 Include optional arrayref of tags/tag-values.
 
@@ -381,7 +381,7 @@ Include optional arrayref of tags/tag-values.
 		value => $metric_value,
 		unit  => $metric_unit, # 'ms' (milliseconds) or 's|sec' (seconds)
 	);
-	
+
 	$dogstatsd->timer(
 		name  => $metric_name,
 		value => $metric_value,
@@ -395,34 +395,34 @@ sub timer
 {
 	my ( $self, %args ) = @_;
 	my $verbose = $self->verbose();
-	
+
 	# Check for mandatory parameters
 	foreach my $arg ( qw( name value unit ) )
 	{
 		croak "Argument '$arg' is a required argument for timer()"
 			if !defined( $args{$arg} ) || ( $args{$arg} eq '' );
 	}
-	
+
 	# Check that value is a positive number
 	croak "Value >$args{'value'}< is not a positive number, which is required for timer()"
 		unless Data::Validate::Type::is_number( $args{'value'}, positive => 1 );
-	
+
 	# Check that unit is one of the accepted values
 	unless ( $args{'unit'} =~ m/^(s|sec|ms)$/ )
 	{
 		croak "Argument 'unit' has invalid value >" . $args{'unit'} . "<. Allowed values are 's', 'sec' or 'ms'";
 	}
-	
+
 	if ( $args{'unit'} eq 's' || $args{'unit'} eq 'sec' )
 	{
 		# Convert to milliseconds
 		$args{'value'} *= 1000;
 		$args{'value'} = sprintf( "%.2f", $args{'value'} ); #for things that run in microseconds
 	}
-	
+
 	# Error checks common to all metric types
 	$self->_error_checks( %args );
-	
+
 	$self->_send_metric(
 		type        => 'timer',
 		value       => $args{'value'},
@@ -430,21 +430,22 @@ sub timer
 		tags        => defined $args{'tags'} ? $args{'tags'} : [],
 		sample_rate => defined $args{'sample_rate'} ? $args{'sample_rate'} : 1,
 	);
-		
+
 	return;
 }
 
 
 =head2 sets()
 
-Send a 'sets' metric. Used to count the number of unique elements in a group. Ex: unique site visitors.
+Send a 'sets' metric. Used to count the number of unique elements in a group.
+Ex: unique site visitors.
 Include optional arrayref of tags/tag-values.
 
 	$dogstatsd->sets(
 		name  => 'unique.site_visitors',
 		value => $account_id,
 	);
-	
+
 	$dogstatsd->sets(
 		name  => 'unique.site_visitors',
 		value => $account_id,
@@ -457,17 +458,17 @@ sub sets
 {
 	my ( $self, %args ) = @_;
 	my $verbose = $self->verbose();
-	
+
 	# Check for mandatory parameters
 	foreach my $arg ( qw( name  value ) )
 	{
 		croak "Argument '$arg' is a required argument"
 			if !defined( $args{$arg} ) || ( $args{$arg} eq '' );
 	}
-	
+
 	# Error checks common to all metric types
 	$self->_error_checks( %args );
-	
+
 	$self->_send_metric(
 		type        => 'sets',
 		value       => $args{'value'},
@@ -475,7 +476,7 @@ sub sets
 		tags        => defined $args{'tags'} ? $args{'tags'} : [],
 		sample_rate => defined $args{'sample_rate'} ? $args{'sample_rate'} : 1,
 	);
-	
+
 	return;
 }
 
@@ -494,45 +495,45 @@ sub sets
 sub _counter
 {
 	my ( $self, %args ) = @_;
-	
+
 	my $action = delete( $args{'action'} );
 	my $multipliers = {
 		'increment' => 1,
 		'decrement' => -1,
 	};
-	
+
 	croak "Error - invalid action >$action<" unless exists( $multipliers->{ $action } );
-		
+
 	my $multiplier = $multipliers->{ $action };
-	
+
 	# Check for mandatory parameters
 	foreach my $arg ( qw( name  ) )
 	{
 		croak "Argument '$arg' is a required argument"
 			if !defined( $args{$arg} ) || ( $args{$arg} eq '' );
 	}
-	
+
 	# Check that value, if provided, is a positive integer
 	if ( defined( $args{'value'} ) )
 	{
 		croak "Value >$args{'value'}< is not a positive integer, which is required for decrement()"
 			if ( $args{'value'} !~ /^\d+$/ || $args{'value'} <= 0 );
 	}
-	
+
 	# Error checks common to all metric types
 	$self->_error_checks( %args );
-	
+
 	$self->_send_metric(
 		type        => 'counter',
 		name        => $args{'name'},
-		value       => 
+		value       =>
 			( defined $args{'value'} && $args{'value'} ne '' )
 				? ( $args{'value'} * $multiplier )
 				: $multiplier,
 		tags        => defined $args{'tags'} ? $args{'tags'} : [],
 		sample_rate => defined $args{'sample_rate'} ? $args{'sample_rate'} : 1,
 	);
-	
+
 	return;
 }
 
@@ -549,47 +550,47 @@ sub _error_checks
 {
 	my ( $self, %args ) = @_;
 	my $verbose = $self->verbose();
-	
+
 	# Metric name starts with a letter
 	if ( $args{'name'} !~ /^[a-zA-Z]/ )
 	{
-		croak( "ERROR - Invalid metric name >" . $args{'name'} . "<. Names must start with a letter, a-z. Not sending." );
+		croak( 'ERROR - Invalid metric name >' . $args{'name'} . '<. Names must start with a letter, a-z. Not sending.' );
 	}
-	
+
 	# Tags, if exist...
 	if ( defined( $args{'tags'} ) && scalar( @{ $args{'tags'} } ) != 0 )
 	{
 		if ( !Data::Validate::Type::is_arrayref( $args{'tags'} ) )
 		{
-			croak "ERROR - Tag list is invalid. Must be an arrayref.";
+			croak 'ERROR - Tag list is invalid. Must be an arrayref.';
 		}
-		
+
 		foreach my $tag ( @{ $args{'tags'} } )
 		{
 			# Must start with a letter
-			croak( "ERROR - Invalid tag >" . $tag . "< on metric >" . $args{'name'} . "<. Tags must start with a letter, a-z. Not sending." )
+			croak( 'ERROR - Invalid tag >' . $tag . '< on metric >' . $args{'name'} . '<. Tags must start with a letter, a-z. Not sending.' )
 				if ( $tag !~ /^[a-zA-Z]/ );
-			
+
 			# Must be < 200 characters [ discovered this limitation while testing. Datadog stated it should truncate, but I received various errors ]
-			croak( "ERROR - Invalid tag >" . $tag . "< on metric >" . $args{'name'} . "<. Tags must be 200 chars or less. Not sending." )
+			croak( 'ERROR - Invalid tag >' . $tag . '< on metric >' . $args{'name'} . '<. Tags must be 200 chars or less. Not sending.' )
 				if ( length( $tag ) > 200 );
-			
+
 			# NOTE: This check isn't required by Datadog, they will allow this through.
 			# However, this tag will not behave as expected in the graphs, if we were to allow it.
-			croak( "ERROR - Invalid tag >" . $tag . "< on metric >" . $args{'name'} . "<. Tags should only contain a single colon (:). Not sending." )
+			croak( 'ERROR - Invalid tag >' . $tag . '< on metric >' . $args{'name'} . '<. Tags should only contain a single colon (:). Not sending.' )
 				if ( $tag =~ /^\S+:\S+:/ );
 		}
 	}
-	
+
 	# Check that optional 'sample_rate' argument is valid ( 1, or a float between 0 and 1 )
 	if ( defined $args{'sample_rate'} )
 	{
 		if ( !Data::Validate::Type::is_number( $args{'sample_rate'} , strictly_positive => 1 ) || $args{'sample_rate'} > 1 )
 		{
-			croak "ERROR - Invalid sample rate >" . $args{'sample_rate'} . "<. Must be 1, or a float between 0 and 1.";
+			croak 'ERROR - Invalid sample rate >' . $args{'sample_rate'} . '<. Must be 1, or a float between 0 and 1.';
 		}
 	}
-	
+
 	return;
 }
 
@@ -604,36 +605,36 @@ sub _send_metric
 {
 	my ( $self, %args ) = @_;
 	my $verbose = $self->verbose();
-	
+
 	# Check for mandatory parameters
 	foreach my $arg ( qw( name type value ) )
 	{
 		croak "Argument '$arg' is a required argument"
 			if !defined( $args{$arg} ) || ( $args{$arg} eq '' );
 	}
-	
+
 	my $original_name = $args{'name'};
 	# Metric name should only contain alphanumeric, "_", ".". Convert anything else to underscore and warn about substitution
 	# NOTE: Datadog will do this for you anyway, but won't warn you what the actual metric name will become.
 	$args{'name'} =~ s/[^a-zA-Z0-9_\.]/_/;
-	
+
 	#TODO change to Log::Any output
-	carp( "WARNING: converted metric name from >$original_name< to >", $args{'name'}, "<. Names should only contain: a-z, 0-9, underscores, and dots/periods." )
+	carp( 'WARNING: converted metric name from >$original_name< to >', $args{'name'}, '<. Names should only contain: a-z, 0-9, underscores, and dots/periods.' )
 		if $args{'name'} ne $original_name;
-	
+
 	# Default sample rate = 1
 	if( !defined( $args{'sample_rate'} ) )
 	{
 		$args{'sample_rate'} = 1;
 	}
-	
+
 	my $socket = $self->get_socket();
 	return unless defined $socket;
-	
+
 	# Datagram format. More info at http://docs.datadoghq.com/guides/dogstatsd/
 	# dashboard.metricname:value|type|@sample_rate|#tag1:value,tag2
-	my $metric_string = $args{'name'} . ":" . $args{'value'} . '|' . $METRIC_TYPES->{ $args{'type'} } . '|@' . $args{'sample_rate'} ;
-	
+	my $metric_string = $args{'name'} . ':' . $args{'value'} . '|' . $METRIC_TYPES->{ $args{'type'} } . '|@' . $args{'sample_rate'} ;
+
 	if ( defined $args{'tags'} && scalar ( @{ $args{'tags'} } ) != 0 )
 	{
 		foreach my $tag ( @{ $args{'tags'} } )
@@ -644,29 +645,29 @@ sub _send_metric
 			# Tags should only contain alphanumeric, "_", "-",".", "/", ":". Convert anything else to underscore and warn about substitution
 			$tag =~ s/[^a-zA-Z0-9_\-\.\/:]/_/g;
 			$tag =~ s/\s+/_/g; # Replace remaining whitespace with underscore
-			carp( "WARNING: converted tag from >$original_tag< to >", $tag, "<. Tags should only contain: a-z, 0-9, underscores, dashes, dots/periods, forward slashes, colons." )
+			carp( "WARNING: converted tag from >$original_tag< to >$tag<. Tags should only contain: a-z, 0-9, underscores, dashes, dots/periods, forward slashes, colons." )
 				if $tag ne $original_tag;
 		}
 		$metric_string .= '|#' . join( ',', @{ $args{'tags'} } );
 	}
-	
+
 	# Force to all lower case because Datadog has case sensitive tags and metric
 	# names. We don't want to end up with multiple case variations of the same
 	# metric name/tag
 	$metric_string = lc( $metric_string );
-	
+
 	carp( "\nbuilt metric string >$metric_string<" ) if $verbose;
-	
+
 	# Use of rand() is how the Ruby and Python clients implement sampling, so we will too.
 	if ( $args{'sample_rate'} == 1 || ( rand() < $args{'sample_rate'} ) )
 	{
 		my $response = IO::Socket::send( $socket, $metric_string, 0 );
-		unless (defined $response) 
+		unless (defined $response)
 		{
 			carp( "error sending metric [string >$metric_string<]: $!" );
 		}
 	}
-	
+
 	return;
 }
 
@@ -696,7 +697,8 @@ Jennifer Pinkham, C<< <jpinkham at cpan.org> >>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests to the GitHub Issue Tracker at L<https://github.com/jpinkham/net-dogstatsd/issues>.
+Please report any bugs or feature requests to the GitHub Issue Tracker at
+L<https://github.com/jpinkham/net-dogstatsd/issues>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
@@ -733,12 +735,12 @@ L<https://metacpan.org/release/Net-Dogstatsd>
 
 =head1 ACKNOWLEDGEMENTS
 
-I originally developed this project for ThinkGeek (L<http://www.thinkgeek.com/>). 
+I originally developed this project for ThinkGeek (L<http://www.thinkgeek.com/>).
 Thanks for allowing me to open-source it!
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2013 Jennifer Pinkham.
+Copyright 2015 Jennifer Pinkham.
 
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 3 as published by the Free
